@@ -2,19 +2,36 @@ import argparse
 import os
 from pathlib import Path
 
+import matplotlib.pyplot as plt
 from dotenv import load_dotenv
 
 from bella_companion.eucovid import run_beast as run_eucovid_beast
 from bella_companion.platyrrhine import plot_platyrrhine_results
 from bella_companion.platyrrhine import run_beast as run_platyrrhine
-from bella_companion.platyrrhine import summarize_logs as summarize_platyrrhine
+from bella_companion.platyrrhine import summarize as summarize_platyrrhine
 from bella_companion.simulations import generate_data, generate_figures, print_metrics
 from bella_companion.simulations import run_beast as run_simulations
-from bella_companion.simulations import summarize_logs as summarize_simulations
+from bella_companion.simulations import summarize as summarize_simulations
 
 
 def main():
     load_dotenv(Path(os.getcwd()) / ".env")
+    os.environ["BELLA_RUN_BEAST_CMD"] = " ".join(
+        [
+            "java",
+            os.getenv("JAVA_OPTIONS", ""),
+            f"-jar {Path(__file__).parent / 'BELLA.jar'}",
+            f"-version_file {Path(__file__).parent / 'version.xml'}",
+            "-overwrite",
+            "-statefile /tmp/state",
+        ]
+    )
+    plt.rcParams["pdf.fonttype"] = 42
+    plt.rcParams["xtick.labelsize"] = 14
+    plt.rcParams["ytick.labelsize"] = 14
+    plt.rcParams["font.size"] = 14
+    plt.rcParams["figure.constrained_layout.use"] = True
+    plt.rcParams["lines.linewidth"] = 3
 
     parser = argparse.ArgumentParser(
         prog="bella",
