@@ -39,22 +39,23 @@ def run_beast():
         command = " ".join(
             [
                 os.environ["BELLA_RUN_BEAST_CMD"],
+                "-seed 42",
                 f'-D types="{",".join(types)}"',
-                f'-D startTypePriorProbs="0.25 0.25 0.25 0.25"',
-                f"-D birthRateUpper=5",
-                f"-D deathRateUpper=5",
-                f'-D samplingChangeTimes="2.58 5.333 23.03"',
-                f"-D samplingRateUpper=5",
-                f'-D samplingRateInit="2.5 2.5 2.5 2.5"',
-                f"-D migrationRateUpper=5",
-                f'-D migrationRateInit="2.5 0 0 2.5 2.5 0 0 2.5 2.5 0 0 2.5"',
-                f'-D nodes="16 8"',
-                f'-D layersRange="0,1,2"',
+                '-D startTypePriorProbs="0.25 0.25 0.25 0.25"',
+                "-D birthRateUpper=5",
+                "-D deathRateUpper=5",
+                '-D samplingChangeTimes="2.58 5.333 23.03"',
+                "-D samplingRateUpper=5",
+                '-D samplingRateInit="2.5 2.5 2.5 2.5"',
+                "-D migrationRateUpper=5",
+                '-D migrationRateInit="2.5 0 0 2.5 2.5 0 0 2.5 2.5 0 0 2.5"',
+                '-D nodes="16 8"',
+                '-D layersRange="0,1,2"',
                 f"-D treeFile={tree_file}",
                 f"-D treeIndex={i}",
                 f"-D changeTimesFile={change_times_file}",
                 f"-D traitsFile={traits_file}",
-                f"-D traitValueCol=3",
+                "-D traitValueCol=3",
                 f"-D processLength={process_length}",
                 f'-D timePredictor="{time_predictor}"',
                 f'-D log10BMPredictor="{log10BM_predictor}"',
