@@ -1,4 +1,5 @@
 import os
+from pathlib import Path
 
 from phylogenie import generate_trees
 
@@ -10,16 +11,17 @@ MAX_TIPS = 500
 
 
 def generate_data():
-    base_output_dir = os.environ["BELLA_SIMULATIONS_DATA_DIR"]
+    base_output_dir = Path(os.environ["BELLA_SIMULATIONS_DATA_DIR"])
     for scenario_name, scenario in SCENARIOS.items():
         generate_trees(
-            output_dir=os.path.join(base_output_dir, scenario_name),
+            output_dir=base_output_dir / scenario_name,
             n_trees=N_TREES,
             events=scenario.events,
             init_state=scenario.init_state,
             sampling_probability_at_present=int(scenario.type == ScenarioType.FBD),
             max_time=scenario.max_time,
-            min_tips=MIN_TIPS,
-            max_tips=MAX_TIPS,
             seed=42,
+            acceptance_criterion=lambda t: MIN_TIPS
+            <= sum(1 for l in t.get_leaves() if l.branch_length > 0)  # pyright: ignore
+            <= MAX_TIPS,
         )
